Package: documentosbr
Type: Package
Title: Validate Brazilian Administrative Registers - Valida Documentos
Version: 0.2.0
Authors@R: c(
    person(
      "Gustavo",
      "Coelho",
      role=c("aut"),
      email="gustavo.coelho@ipea.gov.br"
      ),
    person(
      "Lucas","Mation", 
      role = c("aut"),
      comment = c(ORCID = "0000-0002-7461-932X")
      ),
    person(
      "Rodrigo", "Borges",
      email = "rodrigo.borges@ipea.gov.br",
      role = c("ctb","cre"),
      comment = c(ORCID = "0000-0003-2076-1424")
      ),
    person("Ipea - Institue for Applied Economic Research", role = c("cph", "fnd"))
    )
Maintainer: Rodrigo Borges <rodrigo.borges@ipea.gov.br>
Description: Contains functions to validate administrative register as 
             CPF (Cadastro de Pessoa Fisica), CNPJ (Cadastro de Pessoa Juridica), 
             PIS (Programa de Integracao Social),
             CNES (Cadastro Nacional de Saude). 
             Builds from and improves on previous package from IPEA validaRA <https://github.com/ipea/validaRA>.
             It can check individual registers or help creating a table summarizing validity of a set.
License: GPL-3
Encoding: UTF-8
URL: https://github.com/ipea/documentosbr
BugReports: https://github.com/ipea/documentosbr/issues
Suggests: testthat, knitr, covr, rmarkdown
RoxygenNote: 7.3.2
Depends: R (>= 3.0)
LinkingTo: Rcpp, BH
Imports: Rcpp, bit64, stringr, data.table
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2026-04-28 13:53:01 UTC; borges
Author: Gustavo Coelho [aut],
  Lucas Mation [aut] (ORCID: <https://orcid.org/0000-0002-7461-932X>),
  Rodrigo Borges [ctb, cre] (ORCID:
    <https://orcid.org/0000-0003-2076-1424>),
  Ipea - Institue for Applied Economic Research [cph, fnd]
Repository: CRAN
Date/Publication: 2026-05-05 11:50:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-05-05 13:37:55 UTC; unix
Archs: documentosbr.so.dSYM
