# Generated by roxygen2: do not edit by hand

export(doc2integer64)
export(gera_digito)
export(trata_cpf)
export(valida_doc)
export(valida_doc_df)
export(verificar_titulo_eleitor)
import(bit64)
import(data.table)
import(stringr)
importFrom(Rcpp,sourceCpp)
useDynLib(documentosbr, .registration = TRUE)
