# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

converter_ra_ <- function(x) {
    .Call(`_documentosbr_converter_ra_`, x)
}

valida_ra <- function(x, type, log) {
    .Call(`_documentosbr_valida_ra`, x, type, log)
}

generate_digit <- function(x, type) {
    invisible(.Call(`_documentosbr_generate_digit`, x, type))
}

